..
  This file describes user-visible changes between the versions.

Change History
##############

:1.0.0: released 2020-08-17

    `Initial release
    <https://github.com/prjemian/rpi_dht_epics/releases/tag.1.0.0>`_

:0.3.3:

    `waveforms
    <https://github.com/prjemian/rpi_dht_epics/releases/tag.0.3.3>`_

:0.3.2:

    `IOC shell management
    <https://github.com/prjemian/rpi_dht_epics/releases/tag.0.3.2>`_

:0.3.1:

    `packaging, versioning, and publishing
    <https://github.com/prjemian/rpi_dht_epics/releases/tag.0.3.1>`_

:0.3.0:

    `pre-release
    <https://github.com/prjemian/rpi_dht_epics/releases/tag.0.3.0>`_
    
        * rename repository as *dhtioc*
        * refactor to use (latest) *adafruit_dht* API

:0.2.0:

    `use older DHT API
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.2.0>`_

:0.1.2:

    `analyze signal trends
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.1.2>`_

:0.1.1:

    `add caproto IOC
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.1.1>`_

:0.1.0:

    `restart
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.1.0>`_

:0.0.4:

    `statistics
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.0.4>`_

:0.0.3:

    `EPICS client version
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.0.3>`_

:0.0.2:

    `initial custom code
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.0.2>`_

:0.0.1:

    `proof of example
    <https://github.com/prjemian/rpi_dht_epics/releases/tag/0.0.1>`_

----------

This project uses [sematic versioning](https://semver.org).
